tlslite.constants.HandshakeType

Package tlslite :: Module constants :: Class HandshakeType |
[show private | hide private]
[frames | no frames]

## Class HandshakeType

Class Variable Summary
`int` | `certificate` = 11
`int` | `certificate_request` = 13
`int` | `certificate_verify` = 15
`int` | `client_hello` = 1
`int` | `client_key_exchange` = 16
`int` | `finished` = 20
`int` | `hello_request` = 0
`int` | `server_hello` = 2
`int` | `server_hello_done` = 14
`int` | `server_key_exchange` = 12

Class Variable Details

    ### certificate Type: `int` Value:
        11

    ### certificate_request Type: `int` Value:
        13

    ### certificate_verify Type: `int` Value:
        15

    ### client_hello Type: `int` Value:
        1

    ### client_key_exchange Type: `int` Value:
        16

    ### finished Type: `int` Value:
        20

    ### hello_request Type: `int` Value:
        0

    ### server_hello Type: `int` Value:
        2

    ### server_hello_done Type: `int` Value:
        14

    ### server_key_exchange Type: `int` Value:
        12

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net